@@ -261,6 +261,10 @@ to_string(cudnnBackendBehaviorNote_t note) {
         case CUDNN_BEHAVIOR_NOTE_SUPPORTS_CUDA_GRAPH_NATIVE_API:
             return std::string("CUDNN_BEHAVIOR_NOTE_SUPPORTS_CUDA_GRAPH_NATIVE_API");
 #endif
+#if (CUDNN_VERSION >= 91500)
+        case CUDNN_BEHAVIOR_NOTE_CUBLASLT_DEPENDENCY:
+            return std::string("CUDNN_BEHAVIOR_NOTE_CUBLASLT_DEPENDENCY");
+#endif
 #ifndef NO_DEFAULT_IN_SWITCH
         default:
             return std::string("UNKNOWN_BEHAVIOR_NOTE");
@@ -417,6 +421,22 @@ NLOHMANN_JSON_SERIALIZE_ENUM(NormFwdPhase_t,
                                  {NormFwdPhase_t::TRAINING, "TRAINING"},
                              })
 
+enum class MoeGroupedMatmulMode_t {
+    NOT_SET,
+
+    NONE,
+    GATHER,
+    SCATTER
+};
+
+NLOHMANN_JSON_SERIALIZE_ENUM(MoeGroupedMatmulMode_t,
+                             {
+                                 {MoeGroupedMatmulMode_t::NOT_SET, nullptr},
+                                 {MoeGroupedMatmulMode_t::NONE, "NONE"},
+                                 {MoeGroupedMatmulMode_t::GATHER, "GATHER"},
+                                 {MoeGroupedMatmulMode_t::SCATTER, "SCATTER"},
+                             })
+
 enum class DescriptorType_t {
     NOT_SET,
 
@@ -457,7 +477,8 @@ enum class DescriptorType_t {
     OPERATION_PAGED_CACHE_LOAD_DESCRIPTOR,
     OPERATION_BLOCK_SCALE_QUANTIZE_DESCRIPTOR,
     OPERATION_BLOCK_SCALE_DEQUANTIZE_DESCRIPTOR,
-    OPERATION_CONCATENATE_DESCRIPTOR
+    OPERATION_CONCATENATE_DESCRIPTOR,
+    OPERATION_MOE_GROUPED_MATMUL_DESCRIPTOR
 };
 
 enum class NormMode_t {
@@ -612,6 +633,7 @@ enum class BehaviorNote_t {
     REQUIRES_FILTER_INT8x32_REORDER,
     REQUIRES_BIAS_INT8x32_REORDER,
     SUPPORTS_CUDA_GRAPH_NATIVE_API,
+    CUBLASLT_DEPENDENCY,
 };
 
 NLOHMANN_JSON_SERIALIZE_ENUM(BehaviorNote_t,
@@ -621,6 +643,7 @@ NLOHMANN_JSON_SERIALIZE_ENUM(BehaviorNote_t,
                                  {BehaviorNote_t::REQUIRES_FILTER_INT8x32_REORDER, "REQUIRES_FILTER_INT8x32_REORDER"},
                                  {BehaviorNote_t::REQUIRES_BIAS_INT8x32_REORDER, "REQUIRES_BIAS_INT8x32_REORDER"},
                                  {BehaviorNote_t::SUPPORTS_CUDA_GRAPH_NATIVE_API, "SUPPORTS_CUDA_GRAPH_NATIVE_API"},
+                                 {BehaviorNote_t::CUBLASLT_DEPENDENCY, "CUBLASLT_DEPENDENCY"},
                              })
 
 enum class NumericalNote_t {
@@ -930,6 +953,9 @@ operator<<(std::ostream& os, const DescriptorType_t& mode) {
         case DescriptorType_t::OPERATION_CONCATENATE_DESCRIPTOR:
             os << "OPERATION_CONCATENATE_DESCRIPTOR";
             break;
+        case DescriptorType_t::OPERATION_MOE_GROUPED_MATMUL_DESCRIPTOR:
+            os << "OPERATION_MOE_GROUPED_MATMUL_DESCRIPTOR";
+            break;
         case DescriptorType_t::NOT_SET:
             os << "NOT_SET";
             break;
@@ -1393,12 +1419,20 @@ convert_to_cudnn_type(cudnn_frontend::BehaviorNote_t const mode, cudnnBackendBeh
             return cudnnStatus_t::CUDNN_STATUS_SUCCESS;
         case BehaviorNote_t::SUPPORTS_CUDA_GRAPH_NATIVE_API:
 #if (CUDNN_VERSION >= 90500)
-            NV_CUDNN_FE_DYNAMIC_CHECK_CUDNN_BACKEND_VERSION(90300, cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE);
+            NV_CUDNN_FE_DYNAMIC_CHECK_CUDNN_BACKEND_VERSION(90500, cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE);
             cudnn_mode = CUDNN_BEHAVIOR_NOTE_SUPPORTS_CUDA_GRAPH_NATIVE_API;
             return cudnnStatus_t::CUDNN_STATUS_SUCCESS;
 #else
             return cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE;
 #endif
+        case BehaviorNote_t::CUBLASLT_DEPENDENCY:
+#if (CUDNN_VERSION >= 91500)
+            NV_CUDNN_FE_DYNAMIC_CHECK_CUDNN_BACKEND_VERSION(91500, cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE);
+            cudnn_mode = CUDNN_BEHAVIOR_NOTE_CUBLASLT_DEPENDENCY;
+            return cudnnStatus_t::CUDNN_STATUS_SUCCESS;
+#else
+            return cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE;
+#endif
 
 #ifndef NO_DEFAULT_IN_SWITCH
         default:
@@ -1421,6 +1455,10 @@ convert_from_cudnn_type(cudnnBackendBehaviorNote_t const cudnn_mode) {
         case CUDNN_BEHAVIOR_NOTE_SUPPORTS_CUDA_GRAPH_NATIVE_API:
             return BehaviorNote_t::SUPPORTS_CUDA_GRAPH_NATIVE_API;
 #endif
+#if (CUDNN_VERSION >= 91500)
+        case CUDNN_BEHAVIOR_NOTE_CUBLASLT_DEPENDENCY:
+            return BehaviorNote_t::CUBLASLT_DEPENDENCY;
+#endif
 
 #ifndef NO_DEFAULT_IN_SWITCH
         default:
@@ -1624,6 +1662,14 @@ convert_to_cudnn_type(cudnn_frontend::DescriptorType_t const mode, cudnnBackendD
 #else
             return cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE;
 #endif
+        case DescriptorType_t::OPERATION_MOE_GROUPED_MATMUL_DESCRIPTOR:
+#if (CUDNN_VERSION >= 91500)
+            NV_CUDNN_FE_DYNAMIC_CHECK_CUDNN_BACKEND_VERSION(91500, cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE);
+            cudnn_mode = CUDNN_BACKEND_OPERATION_MOE_GROUPED_MATMUL_DESCRIPTOR;
+            return cudnnStatus_t::CUDNN_STATUS_SUCCESS;
+#else
+            return cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE;
+#endif
 
 #ifndef NO_DEFAULT_IN_SWITCH
         default:
@@ -2025,6 +2071,10 @@ convert_from_cudnn_type(cudnnBackendDescriptorType_t const cudnn_mode) {
         case CUDNN_BACKEND_OPERATION_BLOCK_SCALE_DEQUANTIZE_DESCRIPTOR:
             return DescriptorType_t::OPERATION_BLOCK_SCALE_DEQUANTIZE_DESCRIPTOR;
 #endif
+#if (CUDNN_VERSION >= 91500)
+        case CUDNN_BACKEND_OPERATION_MOE_GROUPED_MATMUL_DESCRIPTOR:
+            return DescriptorType_t::OPERATION_MOE_GROUPED_MATMUL_DESCRIPTOR;
+#endif
 
 #ifndef NO_DEFAULT_IN_SWITCH
         default:
@@ -2345,6 +2395,46 @@ convert_from_cudnn_type(cudnnRngDistribution_t const cudnn_mode) {
 }
 #endif
 
+#if (CUDNN_VERSION >= 91500)
+static inline cudnnStatus_t
+convert_to_cudnn_type(cudnn_frontend::MoeGroupedMatmulMode_t const mode, cudnnMoeGroupedMatmulMode_t& cudnn_mode) {
+    NV_CUDNN_FE_DYNAMIC_CHECK_CUDNN_BACKEND_VERSION(91500, cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE);
+    switch (mode) {
+        case MoeGroupedMatmulMode_t::NONE:
+            cudnn_mode = CUDNN_MOE_GROUPED_MATMUL_MODE_NONE;
+            return cudnnStatus_t::CUDNN_STATUS_SUCCESS;
+        case MoeGroupedMatmulMode_t::GATHER:
+            cudnn_mode = CUDNN_MOE_GROUPED_MATMUL_MODE_GATHER;
+            return cudnnStatus_t::CUDNN_STATUS_SUCCESS;
+        case MoeGroupedMatmulMode_t::SCATTER:
+            cudnn_mode = CUDNN_MOE_GROUPED_MATMUL_MODE_SCATTER;
+            return cudnnStatus_t::CUDNN_STATUS_SUCCESS;
+#ifndef NO_DEFAULT_IN_SWITCH
+        default:
+            return cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE;
+#endif
+    }
+    return cudnnStatus_t::CUDNN_STATUS_INVALID_VALUE;
+}
+
+static inline cudnn_frontend::MoeGroupedMatmulMode_t
+convert_from_cudnn_type(cudnnMoeGroupedMatmulMode_t const cudnn_mode) {
+    switch (cudnn_mode) {
+        case CUDNN_MOE_GROUPED_MATMUL_MODE_NONE:
+            return MoeGroupedMatmulMode_t::NONE;
+        case CUDNN_MOE_GROUPED_MATMUL_MODE_GATHER:
+            return MoeGroupedMatmulMode_t::GATHER;
+        case CUDNN_MOE_GROUPED_MATMUL_MODE_SCATTER:
+            return MoeGroupedMatmulMode_t::SCATTER;
+#ifndef NO_DEFAULT_IN_SWITCH
+        default:
+            return MoeGroupedMatmulMode_t::NOT_SET;
+#endif
+    }
+    return MoeGroupedMatmulMode_t::NOT_SET;
+}
+#endif
+
 std::string static get_engine_tag(ManagedOpaqueDescriptor const config) {
     std::stringstream tag{""};
     ManagedOpaqueDescriptor extractedEngine = make_shared_backend_pointer(CUDNN_BACKEND_ENGINE_DESCRIPTOR);
