@@ -111,11 +111,11 @@ layernorm_fwd_dynamic_shapes(bool train = true) {
             SKIP("Kernel cache not supported pre 9.4");
         }
 
-        REQUIRE(graph.create_execution_plans({fe::HeurMode_t::A}).is_good());
+        REQUIRE(graph.create_execution_plans({fe::HeurMode_t::A, fe::HeurMode_t::FALLBACK}).is_good());
 
-        REQUIRE(graph.check_support(handle).is_good());
+        REQUIRE(graph.check_support().is_good());
 
-        REQUIRE(graph.build_plans(handle, fe::BuildPlanPolicy_t::ALL).is_good());
+        REQUIRE(graph.build_plans(fe::BuildPlanPolicy_t::ALL).is_good());
 
         return std::make_tuple(graph, X, scale, bias, Y, mean, inv_variance);
     };
@@ -219,11 +219,11 @@ TEST_CASE("LayerNorm Training", "[layernorm][graph]") {
 
     REQUIRE(graph.build_operation_graph(handle).is_good());
 
-    REQUIRE(graph.create_execution_plans({fe::HeurMode_t::FALLBACK}).is_good());
+    REQUIRE(graph.create_execution_plans({fe::HeurMode_t::A, fe::HeurMode_t::FALLBACK}).is_good());
 
-    REQUIRE(graph.check_support(handle).is_good());
+    REQUIRE(graph.check_support().is_good());
 
-    REQUIRE(graph.build_plans(handle).is_good());
+    REQUIRE(graph.build_plans().is_good());
 
     Surface<half> X_tensor(batch_size * seq_length * hidden_size, false);
     Surface<float> Mean_tensor(batch_size * seq_length, false);
@@ -298,11 +298,11 @@ TEST_CASE("LayerNorm Inference", "[layernorm][graph]") {
 
     REQUIRE(graph.build_operation_graph(handle).is_good());
 
-    REQUIRE(graph.create_execution_plans({fe::HeurMode_t::FALLBACK}).is_good());
+    REQUIRE(graph.create_execution_plans({fe::HeurMode_t::A, fe::HeurMode_t::FALLBACK}).is_good());
 
-    REQUIRE(graph.check_support(handle).is_good());
+    REQUIRE(graph.check_support().is_good());
 
-    REQUIRE(graph.build_plans(handle).is_good());
+    REQUIRE(graph.build_plans().is_good());
 
     Surface<half> X_tensor(batch_size * seq_length * hidden_size, false);
     Surface<float> Scale_tensor(hidden_size, false);
@@ -375,11 +375,11 @@ TEST_CASE("LayerNorm Backward", "[layernorm][graph]") {
 
     REQUIRE(graph.build_operation_graph(handle).is_good());
 
-    REQUIRE(graph.create_execution_plans({fe::HeurMode_t::FALLBACK}).is_good());
+    REQUIRE(graph.create_execution_plans({fe::HeurMode_t::A, fe::HeurMode_t::FALLBACK}).is_good());
 
-    REQUIRE(graph.check_support(handle).is_good());
+    REQUIRE(graph.check_support().is_good());
 
-    REQUIRE(graph.build_plans(handle).is_good());
+    REQUIRE(graph.build_plans().is_good());
 
     Surface<half> X_tensor(batch_size * seq_length * hidden_size, false);
     Surface<half> DY_tensor(batch_size * seq_length * hidden_size, false);
