@@ -68,11 +68,13 @@ TEST_CASE("RmsNorm Training", "[rmsnorm][graph]") {
 
     REQUIRE(graph.build_operation_graph(handle).is_good());
 
-    REQUIRE(graph.create_execution_plans({fe::HeurMode_t::FALLBACK}).is_good());
+    REQUIRE(graph.create_execution_plans({fe::HeurMode_t::A, fe::HeurMode_t::FALLBACK}).is_good());
 
-    REQUIRE(graph.check_support(handle).is_good());
+    REQUIRE(graph.check_support().is_good());
 
-    REQUIRE(graph.build_plans(handle).is_good());
+    REQUIRE(graph.build_plans().is_good());
+
+    REQUIRE(graph.warmup(handle).is_good());
 
     Surface<float> X_tensor(batch_size * seq_length * hidden_size, false);
     Surface<float> Var_tensor(batch_size * seq_length, false);
@@ -139,11 +141,11 @@ TEST_CASE("RmsNorm Inference", "[rmsnorm][graph]") {
 
     REQUIRE(graph.build_operation_graph(handle).is_good());
 
-    REQUIRE(graph.create_execution_plans({fe::HeurMode_t::FALLBACK}).is_good());
+    REQUIRE(graph.create_execution_plans({fe::HeurMode_t::A, fe::HeurMode_t::FALLBACK}).is_good());
 
-    REQUIRE(graph.check_support(handle).is_good());
+    REQUIRE(graph.check_support().is_good());
 
-    REQUIRE(graph.build_plans(handle).is_good());
+    REQUIRE(graph.build_plans().is_good());
 
     Surface<float> X_tensor(batch_size * seq_length * hidden_size, false);
     Surface<float> Scale_tensor(hidden_size, false);
@@ -211,11 +213,11 @@ TEST_CASE("RmsNorm Backward", "[rmsnorm][graph]") {
 
     REQUIRE(graph.build_operation_graph(handle).is_good());
 
-    REQUIRE(graph.create_execution_plans({fe::HeurMode_t::A}).is_good());
+    REQUIRE(graph.create_execution_plans({fe::HeurMode_t::A, fe::HeurMode_t::FALLBACK}).is_good());
 
-    REQUIRE(graph.check_support(handle).is_good());
+    REQUIRE(graph.check_support().is_good());
 
-    REQUIRE(graph.build_plans(handle).is_good());
+    REQUIRE(graph.build_plans().is_good());
 
     Surface<float> X_tensor(batch_size * seq_length * hidden_size, false);
     Surface<float> DY_tensor(batch_size * seq_length * hidden_size, false);
