@@ -54,12 +54,12 @@ create_sdpa_forward_graph(int64_t const b,
                           int64_t const s_kv,
                           int64_t const d_qk,
                           int64_t const d_v,
-                          float const attn_scale  = 1.0f,
-                          bool const is_inference = false,
-                          bool const causal_mask  = false,
-                          bool const alibi_mask   = false,
-                          bool const padding_mask = false,
-                          bool has_attn_bias      = false) {
+                          float const attn_scale    = 1.0f,
+                          bool const generate_stats = true,
+                          bool const causal_mask    = false,
+                          bool const alibi_mask     = false,
+                          bool const padding_mask   = false,
+                          bool has_attn_bias        = false) {
     // Create a graph and set common global properties.
     auto graph = std::make_shared<fe::graph::Graph>();
     graph->set_io_data_type(fe::DataType_t::BFLOAT16)
@@ -86,7 +86,7 @@ create_sdpa_forward_graph(int64_t const b,
 
     auto sdpa_options = fe::graph::SDPA_attributes()
                             .set_name("flash_attention")
-                            .set_is_inference(is_inference)
+                            .set_generate_stats(generate_stats)
                             .set_alibi_mask(alibi_mask)
                             .set_attn_scale(attn_scale);
 
@@ -99,6 +99,7 @@ create_sdpa_forward_graph(int64_t const b,
         auto bias = graph->tensor(fe::graph::Tensor_attributes()
                                       .set_name("bias")
                                       .set_uid(BIAS_UID)
+                                      .set_data_type(fe::DataType_t::HALF)
                                       .set_dim({b, 1, s_q, s_kv})
                                       .set_stride({s_q * s_kv, s_q * s_kv, s_kv, 1}));
         sdpa_options.set_bias(bias);
@@ -124,30 +125,30 @@ create_sdpa_forward_graph(int64_t const b,
 
     O->set_output(true).set_dim({b, h_q, s_q, d_v}).set_stride({h_q * d_v, d_v, b * h_q * d_v, 1}).set_uid(O_UID);
 
-    if (is_inference) {
-        assert(Stats == nullptr);
-    } else {
+    if (generate_stats) {
         Stats->set_output(true).set_data_type(fe::DataType_t::FLOAT).set_uid(STATS_UID);
+    } else {
+        assert(Stats == nullptr);
     }
 
     return graph;
 }
 
 TEST_CASE("Toy sdpa forward", "[graph][sdpa][flash][forward]") {
-    int64_t b          = 3;     // batch size
-    int64_t h_q        = 4;     // head dim
-    int64_t h_k        = 4;     // head dim
-    int64_t h_v        = 4;     // head dim
-    int64_t s_q        = 1024;  // q tensor is padded to this seq length
-    int64_t s_kv       = 1024;  // k and v tensor is padded to this seq length
-    int64_t d_qk       = 128;   // hidden dim
-    int64_t d_v        = 128;   // hidden dim
-    bool is_inference  = false;
-    float attn_scale   = 0.123f;
-    bool causal_mask   = true;
-    bool padding_mask  = (cudnnGetVersion() >= 8903);
-    bool alibi_mask    = (cudnnGetVersion() >= 8904);
-    bool has_attn_bias = (cudnnGetVersion() >= 8903);
+    int64_t b           = 3;     // batch size
+    int64_t h_q         = 4;     // head dim
+    int64_t h_k         = 4;     // head dim
+    int64_t h_v         = 4;     // head dim
+    int64_t s_q         = 1024;  // q tensor is padded to this seq length
+    int64_t s_kv        = 1024;  // k and v tensor is padded to this seq length
+    int64_t d_qk        = 128;   // hidden dim
+    int64_t d_v         = 128;   // hidden dim
+    bool generate_stats = true;
+    float attn_scale    = 0.123f;
+    bool causal_mask    = true;
+    bool padding_mask   = (cudnnGetVersion() >= 8903);
+    bool alibi_mask     = (cudnnGetVersion() >= 8904);
+    bool has_attn_bias  = (cudnnGetVersion() >= 8903);
 
     if (cudnnGetVersion() < 8903) {
         SKIP("Test requires cudnn 8.9.3 or above");
@@ -167,7 +168,7 @@ TEST_CASE("Toy sdpa forward", "[graph][sdpa][flash][forward]") {
                                            d_qk,
                                            d_v,
                                            attn_scale,
-                                           is_inference,
+                                           generate_stats,
                                            causal_mask,
                                            alibi_mask,
                                            padding_mask,
@@ -211,7 +212,7 @@ TEST_CASE("Toy sdpa forward", "[graph][sdpa][flash][forward]") {
     }
 
     Surface<float> statsTensor(b * h_q * s_q * 1, false);
-    if (is_inference == false) {
+    if (generate_stats == true) {
         variant_pack[STATS_UID] = statsTensor.devPtr;
     }
 
