@@ -106,9 +106,9 @@ def test_gemm_silu_and_mul(cudnn_handle):
     # C_fp8.set_output(True)
 
     try:
-        graph.build([cudnn.heur_mode.A])
+        graph.build([cudnn.heur_mode.A, cudnn.heur_mode.FALLBACK])
     except cudnn.cudnnGraphNotSupportedError as e:
-        pytest.xfail(repr(e))
+        pytest.skip(repr(e))
     except Exception as e:
         pytest.fail(repr(e))
 
@@ -204,7 +204,16 @@ def test_silu_and_mul_and_quantization(cudnn_handle):
     C_fp8 = graph.mul(C_fp32, C_Q)
     C_fp8.set_output(True).set_data_type(cudnn.data_type.FP8_E4M3)
 
-    graph.build([cudnn.heur_mode.A])
+    try:
+        graph.build_operation_graph()
+        graph.create_execution_plans([cudnn.heur_mode.A, cudnn.heur_mode.FALLBACK])
+        graph.check_support()
+    except cudnn.cudnnGraphNotSupportedError as e:
+        print(f"TEST WAIVED: unsupported graph. {e}")
+        pytest.skip("TEST WAIVED: unsupported graph.")
+
+    graph.build_plans(cudnn.build_plan_policy.HEURISTICS_CHOICE)
+
     workspace = torch.empty(
         graph.get_workspace_size(), device="cuda", dtype=torch.uint8
     )
